Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ResultDB ¶
type ResultDB interface {
InitGenesis(genesisBlock *serialization.BlockWithSerializedInfo) error
// CommitBlock commits the block rwsets in an atomic operation
CommitBlock(blockInfo *serialization.BlockWithSerializedInfo, isCache bool) error
// ShrinkBlocks archive old blocks rwsets in an atomic operation
ShrinkBlocks(txIdsMap map[uint64][]string) error
// RestoreBlocks restore blocks from outside serialized block data
RestoreBlocks(blockInfos []*serialization.BlockWithSerializedInfo) error
// GetTxRWSet returns an txRWSet for given txId, or returns nil if none exists.
GetTxRWSet(txid string) (*commonPb.TxRWSet, error)
// GetRWSetIndex returns the offset of the rwset in the file
GetRWSetIndex(txId string) (*storePb.StoreInfo, error)
// GetLastSavepoint returns the last block height
GetLastSavepoint() (uint64, error)
// Close is used to close database
Close()
}
ResultDB provides handle to rwSets instances
Click to show internal directories.
Click to hide internal directories.